@@ -5,7 +5,7 @@ from spotPython.hyperdict.light_hyper_dict import LightHyperDict
 from spotPython.hyperparameters.values import add_core_model_to_fun_control, get_default_hyperparameters_as_array
 from spotPython.fun.hyperlight import HyperLight
 from spotPython.data.diabetes import Diabetes
-from spotPython.hyperparameters.values import set_data_set
+from spotPython.hyperparameters.values import set_control_key_value
 import numpy as np
 
 
@@ -15,8 +15,10 @@ def test_hyper_light_fun():
         _L_out=1,)
 
     dataset = Diabetes()
-    set_data_set(fun_control=fun_control,
-                    data_set=dataset)
+    set_control_key_value(control_dict=fun_control,
+                          key="data_set",
+                          value=dataset)
+
 
     add_core_model_to_fun_control(core_model=NetLightRegression,
                                 fun_control=fun_control,
