@@ -4,7 +4,7 @@ from spotPython.light.regression.netlightregression import NetLightRegression
 from spotPython.hyperdict.light_hyper_dict import LightHyperDict
 from spotPython.hyperparameters.values import add_core_model_to_fun_control, get_default_hyperparameters_as_array
 from spotPython.data.diabetes import Diabetes
-from spotPython.hyperparameters.values import set_data_set
+from spotPython.hyperparameters.values import set_control_key_value
 from spotPython.hyperparameters.values import get_var_name, assign_values, generate_one_config_from_var_dict
 from spotPython.light.trainmodel import train_model
 
@@ -15,8 +15,10 @@ def test_trainmodel():
         _L_out=1,)
 
     dataset = Diabetes()
-    set_data_set(fun_control=fun_control,
-                    data_set=dataset)
+    set_control_key_value(control_dict=fun_control,
+                          key="data_set",
+                          value=dataset,
+                          replace=True)
 
     add_core_model_to_fun_control(core_model=NetLightRegression,
                                 fun_control=fun_control,
